@@ -103,7 +103,22 @@ class Bitbucket(AtlassianRestAPI):
             project_key=project_key,
             permission=permission,
             username=username)
+        return self.put(url)
 
+    def repo_grant_user_permissions(self, project_key, repo_key, username, permission):
+        """
+        Grant the specified repository permission to an specific user
+        :param project_key: project key involved
+        :param repo_key: repository key involved (slug)
+        :param user: user name to be granted
+        :param permission: the repository permissions available are 'REPO_ADMIN', 'REPO_WRITE' and 'REPO_READ'
+        :return: 
+        """
+        url = 'rest/api/1.0/projects/{project_key}/repos/{repo_key}/permissions/users?permission={permission}&name={username}'.format(
+            project_key=project_key,
+            repo_key=repo_key,
+            permission=permission,
+            username=username)
         return self.put(url)
 
     def project_groups(self, key, limit=99999, filter_str=None):
